# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.image_response import ImageResponse

class TestImageResponse(unittest.TestCase):
    """ImageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageResponse:
        """Test ImageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageResponse`
        """
        model = ImageResponse()
        if include_optional:
            return ImageResponse(
                image_id = '',
                project_id = '',
                user_id = '',
                filename = '',
                status = '',
                annotations_count = 56,
                annotations = instalabel.client.models.annotation_data.AnnotationData(
                    rectangles = [
                        instalabel.client.models.b_box_annotation.BBoxAnnotation(
                            id = '', 
                            class_id = '', 
                            class_name = '', 
                            color = '', 
                            type = 'boundingBox', 
                            class_attributes_selections = {
                                'key' : [
                                    ''
                                    ]
                                }, 
                            class_information = instalabel.client.models.class_information.ClassInformation(
                                id = '', 
                                name = '', 
                                color = '', 
                                description = '', 
                                attributes_selections_id_map = {
                                    'key' : [
                                        ''
                                        ]
                                    }, 
                                attributes_selections = [
                                    instalabel.client.models.attribute_selection.AttributeSelection(
                                        name = '', 
                                        labels = [
                                            ''
                                            ], 
                                        values = [
                                            ''
                                            ], )
                                    ], ), 
                            x = 56, 
                            y = 56, 
                            width = 56, 
                            height = 56, 
                            fill = '', 
                            stroke = '', )
                        ], 
                    polygons = [
                        instalabel.client.models.polygon_annotation.PolygonAnnotation(
                            id = '', 
                            class_id = '', 
                            class_name = '', 
                            color = '', 
                            type = 'polygon', 
                            class_attributes_selections = {
                                'key' : [
                                    ''
                                    ]
                                }, 
                            class_information = instalabel.client.models.class_information.ClassInformation(
                                id = '', 
                                name = '', 
                                color = '', 
                                description = '', 
                                attributes_selections_id_map = {
                                    'key' : [
                                        ''
                                        ]
                                    }, ), 
                            points = [
                                [
                                    56
                                    ]
                                ], 
                            is_complete = True, )
                        ], ),
                created_at = '',
                updated_at = '',
                presigned_url = ''
            )
        else:
            return ImageResponse(
                image_id = '',
                project_id = '',
                user_id = '',
                filename = '',
                status = '',
                annotations_count = 56,
                created_at = '',
                updated_at = '',
                presigned_url = '',
        )
        """

    def testImageResponse(self):
        """Test ImageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.polygon_annotation import PolygonAnnotation

class TestPolygonAnnotation(unittest.TestCase):
    """PolygonAnnotation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolygonAnnotation:
        """Test PolygonAnnotation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolygonAnnotation`
        """
        model = PolygonAnnotation()
        if include_optional:
            return PolygonAnnotation(
                id = '',
                class_id = '',
                class_name = '',
                color = '',
                type = 'polygon',
                class_attributes_selections = {
                    'key' : [
                        ''
                        ]
                    },
                class_information = instalabel.client.models.class_information.ClassInformation(
                    id = '', 
                    name = '', 
                    color = '', 
                    description = '', 
                    attributes_selections_id_map = {
                        'key' : [
                            ''
                            ]
                        }, 
                    attributes_selections = [
                        instalabel.client.models.attribute_selection.AttributeSelection(
                            name = '', 
                            labels = [
                                ''
                                ], 
                            values = [
                                ''
                                ], )
                        ], ),
                points = [
                    [
                        56
                        ]
                    ],
                is_complete = True
            )
        else:
            return PolygonAnnotation(
                id = '',
                class_id = '',
                class_name = '',
                color = '',
                class_information = instalabel.client.models.class_information.ClassInformation(
                    id = '', 
                    name = '', 
                    color = '', 
                    description = '', 
                    attributes_selections_id_map = {
                        'key' : [
                            ''
                            ]
                        }, 
                    attributes_selections = [
                        instalabel.client.models.attribute_selection.AttributeSelection(
                            name = '', 
                            labels = [
                                ''
                                ], 
                            values = [
                                ''
                                ], )
                        ], ),
                points = [
                    [
                        56
                        ]
                    ],
        )
        """

    def testPolygonAnnotation(self):
        """Test PolygonAnnotation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.api.projects_api import ProjectsApi


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProjectsApi()

    def tearDown(self) -> None:
        pass

    def test_create_project_api_v1_projects_post(self) -> None:
        """Test case for create_project_api_v1_projects_post

        Create Project
        """
        pass

    def test_read_project_api_v1_projects_project_id_get(self) -> None:
        """Test case for read_project_api_v1_projects_project_id_get

        Read Project
        """
        pass

    def test_read_projects_api_v1_projects_get(self) -> None:
        """Test case for read_projects_api_v1_projects_get

        Read Projects
        """
        pass

    def test_update_project_api_v1_projects_project_id_put(self) -> None:
        """Test case for update_project_api_v1_projects_project_id_put

        Update Project
        """
        pass


if __name__ == '__main__':
    unittest.main()



from typing import Any, Dict, Optional

import instalabel.client
from instalabel.client.models.annotation_data import AnnotationData
from instalabel.client.models.image_response import ImageResponse
from instalabel.config import INSTALABEL_CLIENT_CONFIGURATION as configuration


class Image:
    def __init__(self, image: ImageResponse):
        self.id = image.image_id
        self.project_id = image.project_id
        self.user_id = image.user_id
        self.filename = image.filename
        self.status = image.status
        self.annotations_count = image.annotations_count
        self.annotations = image.annotations
        self.created_at = image.created_at
        self.updated_at = image.updated_at
        self.presigned_url = image.presigned_url

    def refresh(self) -> bool:
        """Refresh image data from the server"""
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.ImagesApi(api_client)

            try:
                api_response = api_instance.get_image_api_v1_images_image_id_get(
                    image_id=self.id, project_id=self.project_id
                )
                self.__init__(api_response)
                return True
            except Exception as e:
                print(f"Exception when getting image: {e}")
                return False

    def get_annotations(self) -> AnnotationData:
        """Get image annotations"""
        return self.annotations

    def __str__(self):
        return (
            f"Image(ID: {self.id}, Filename: {self.filename}, Status: {self.status}, "
            f"Annotation Count: {self.annotations_count}, Created At: {self.created_at})"
        )



import os
from typing import Dict, List, Optional

import instalabel.client
from instalabel.client.models.task_enum import TaskEnum
from instalabel.client.rest import ApiException
from instalabel.config import INSTALABEL_CLIENT_CONFIGURATION as configuration
from instalabel.core.project import Project
from instalabel.core.workspace import Workspace


class InstaLabel:
    def __init__(self):
        self.configuration = configuration

    def login(self, username: str, password: str) -> bool:
        """Login to InstaLabel and get access token"""
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.AuthApi(api_client)
            try:
                api_response = (
                    api_instance.login_for_access_token_api_v1_auth_token_post(
                        username=username, password=password
                    )
                )
                configuration.access_token = api_response.access_token
                os.environ["ACCESS_TOKEN"] = api_response.access_token
                return True
            except ApiException as e:
                print(f"Exception when logging in: {e}")
                return False

    def create_workspace(
        self, workspace_name: str, description: str = None
    ) -> Optional[Workspace]:
        """Create a new workspace"""
        return Workspace.create(workspace_name, description)

    def get_workspaces(self) -> List[Workspace]:
        """Get all workspaces"""
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.WorkspacesApi(api_client)
            try:
                api_response = api_instance.read_workspaces_api_v1_workspaces_get()
                return [Workspace(workspace) for workspace in api_response]
            except Exception as e:
                print(f"Exception when getting workspaces: {e}")
                return []

    def get_workspace(self, workspace_id: str) -> Optional[Workspace]:
        """Get a specific workspace by ID"""
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.WorkspacesApi(api_client)
            try:
                api_response = (
                    api_instance.read_workspace_api_v1_workspaces_workspace_id_get(
                        workspace_id
                    )
                )
                return Workspace(api_response)
            except Exception as e:
                print(f"Exception when getting workspace: {e}")
                return None

    def __str__(self):
        return "InstaLabel Client"



from concurrent.futures import ThreadPoolExecutor
from pathlib import Path
from typing import List, Optional

from tqdm import tqdm

import instalabel.client
from instalabel.client.models.coco_dataset import CocoDataset
from instalabel.client.models.coco_upload_request import CocoUploadRequest
from instalabel.client.models.project_response import ProjectResponse
from instalabel.client.models.project_update_request import ProjectUpdateRequest
from instalabel.config import INSTALABEL_CLIENT_CONFIGURATION as configuration
from instalabel.core.image import Image


class Project:
    def __init__(self, project: ProjectResponse):
        self.id = project.project_id
        self.name = project.project_name
        self.description = project.project_description
        self.workspace_id = project.workspace_id
        self.task = project.task
        self.created_at = project.created_at
        self.updated_at = project.updated_at
        self.image_count = project.image_count
        self.ontology = project.ontology

    def upload_single_image(self, file_path: str) -> Optional[Image]:
        """Upload a single image to the project"""
        supported_extensions = (".jpg", ".jpeg", ".png")

        # Check if the file format is supported
        if not str(file_path).lower().endswith(supported_extensions):
            print(f"Unsupported file format for {file_path}. Skipping upload.")
            return None

        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.ImagesApi(api_client)

            try:
                api_response = api_instance.upload_image_api_v1_images_post(
                    project_id=self.id, file=file_path  # Pass the file path directly
                )
                return Image(api_response)
            except Exception as e:
                print(f"Exception when uploading image: {e}")
                return None

    def upload_images(self, image_paths: List[str]) -> None:
        """Upload multiple images in parallel"""

        def upload(image_path: str):
            self.upload_single_image(image_path)

        # Using ThreadPoolExecutor for parallel uploads
        with ThreadPoolExecutor() as executor:
            list(
                tqdm(
                    executor.map(upload, image_paths),
                    total=len(image_paths),
                    desc="Uploading images",
                )
            )

    def upload_directory(self, dataset_path: str) -> None:
        """Upload all images from a directory"""
        dataset_path = Path(dataset_path)

        # Check if the dataset_path exists
        if not dataset_path.exists():
            print(f"Dataset path {dataset_path} does not exist.")
            return

        # Get all image files from the dataset directory
        supported_extensions = (".jpg", ".jpeg", ".png")
        image_paths = [
            str(file_path)
            for file_path in dataset_path.rglob("*")
            if file_path.suffix.lower() in supported_extensions
        ]

        if not image_paths:
            print(f"No supported images found in {dataset_path}")
            return

        print(f"Found {len(image_paths)} images in the dataset.")
        # Upload all images found in the dataset
        self.upload_images(image_paths)

    def update(
        self,
        project_name: Optional[str] = None,
        project_description: Optional[str] = None,
    ) -> bool:
        """Update project details"""
        if project_name is None and project_description is None:
            print("Please provide either project_name or project_description")
            return False

        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.ProjectsApi(api_client)
            update_request = instalabel.client.ProjectUpdateRequest(
                project_name=project_name, project_description=project_description
            )

            try:
                api_response = (
                    api_instance.update_project_api_v1_projects_project_id_put(
                        project_id=self.id, project_update_request=update_request
                    )
                )
                # Update local object with response data
                self.__init__(api_response)
                return True
            except Exception as e:
                print(f"Exception when updating project: {e}")
                return False

    def get_images(self, limit: Optional[int] = None) -> List[Image]:
        """Get all images in the project with pagination support

        Args:
            limit: Optional maximum number of images to return per page. If None, returns all images.

        Returns:
            List[Image]: List of images in the project
        """
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.ImagesApi(api_client)
            images = []
            last_evaluated_key = None

            try:
                # Initialize progress bar
                pbar = tqdm(
                    desc="Fetching images",
                    unit=" images",
                    initial=0,
                    total=limit if limit else self.image_count,
                )

                while True:
                    api_response = api_instance.get_project_images_api_v1_images_get(
                        project_id=self.id,
                        limit=limit,
                        last_evaluated_key=last_evaluated_key,
                    )

                    # Get new images from current page
                    new_images = [Image(image) for image in api_response.images]
                    images.extend(new_images)

                    # Update progress bar with new images
                    pbar.update(len(new_images))

                    # Update description with current count
                    pbar.set_description(f"Retrieved {len(images)} images")

                    # Check if we've reached the last page
                    if not api_response.next_key:
                        break

                    last_evaluated_key = api_response.next_key

                    # If limit is specified, we only want one page
                    if limit is not None:
                        break

                pbar.close()
                return images

            except Exception as e:
                print(f"Exception when getting project images: {e}")
                return []

    def upload_coco_from_s3(self, integration_id: str, coco_data: dict) -> List[Image]:
        """Upload images from an S3 bucket using COCO format annotations.

        Args:
            integration_id (str): AWS integration ID for accessing the S3 bucket
            coco_data (CocoDataset): COCO format annotation data containing image paths and annotations

        Returns:
            List[Image]: List of created images with their details

        Raises:
            Exception: If there's an error during the upload process
        """

        coco_data_dict = CocoDataset(**coco_data).model_dump()

        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.ImagesApi(api_client)

            try:
                # Create the upload request
                upload_request = CocoUploadRequest(
                    integration_id=integration_id, coco_data=coco_data_dict
                )

                # Make the API call
                api_response = api_instance.upload_images_with_coco_api_v1_images_external_s3_coco_upload_post(
                    project_id=self.id, coco_upload_request=upload_request
                )

                # Convert API response to Image objects
                return [Image(image) for image in api_response]

            except Exception as e:
                print(f"Exception when uploading COCO dataset: {e}")
                raise

    def __str__(self):
        return (
            f"Project(ID: {self.id}, Name: {self.name}, Task: {self.task.value}, "
            f"Image Count: {self.image_count}, Created At: {self.created_at})"
        )



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from instalabel.client.models.class_information import ClassInformation
from typing import Optional, Set
from typing_extensions import Self

class BBoxAnnotation(BaseModel):
    """
    Represents a bounding box annotation, extending the base annotation with specific fields for bounding boxes.  Attributes:     x (int): The x-coordinate of the top-left corner of the bounding box.     y (int): The y-coordinate of the top-left corner of the bounding box.     width (int): The width of the bounding box.     height (int): The height of the bounding box.     fill (str): The fill hexadecimal color for the bounding box.     stroke (str): The stroke hexadecimal color for the bounding box.
    """ # noqa: E501
    id: StrictStr = Field(description="A unique identifier for the annotation.")
    class_id: StrictStr = Field(description="The identifier of the class associated with the annotation.", alias="classId")
    class_name: StrictStr = Field(description="The name of the class associated with the annotation.", alias="className")
    color: StrictStr = Field(description="The color used for the annotation.")
    type: Optional[StrictStr] = Field(default='boundingBox', description="The type of annotation ('boundingBox').")
    class_attributes_selections: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="A dictionary mapping attribute IDs to lists of selected values.", alias="classAttributesSelections")
    class_information: ClassInformation = Field(description="Metadata about the class associated with the annotation.", alias="classInformation")
    x: StrictInt = Field(description="The x-coordinate of the top-left corner of the bounding box.")
    y: StrictInt = Field(description="The y-coordinate of the top-left corner of the bounding box.")
    width: StrictInt = Field(description="The width of the bounding box.")
    height: StrictInt = Field(description="The height of the bounding box.")
    fill: StrictStr = Field(description="The fill color for the bounding box.")
    stroke: StrictStr = Field(description="The stroke color for the bounding box.")
    __properties: ClassVar[List[str]] = ["id", "classId", "className", "color", "type", "classAttributesSelections", "classInformation", "x", "y", "width", "height", "fill", "stroke"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BBoxAnnotation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of class_information
        if self.class_information:
            _dict['classInformation'] = self.class_information.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BBoxAnnotation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "classId": obj.get("classId"),
            "className": obj.get("className"),
            "color": obj.get("color"),
            "type": obj.get("type") if obj.get("type") is not None else 'boundingBox',
            "classAttributesSelections": obj.get("classAttributesSelections"),
            "classInformation": ClassInformation.from_dict(obj["classInformation"]) if obj.get("classInformation") is not None else None,
            "x": obj.get("x"),
            "y": obj.get("y"),
            "width": obj.get("width"),
            "height": obj.get("height"),
            "fill": obj.get("fill"),
            "stroke": obj.get("stroke")
        })
        return _obj





# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.api.aws_integrations_api import AwsIntegrationsApi


class TestAwsIntegrationsApi(unittest.TestCase):
    """AwsIntegrationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AwsIntegrationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_integration_api_v1_aws_integrations_post(self) -> None:
        """Test case for create_integration_api_v1_aws_integrations_post

        Create Integration
        """
        pass

    def test_delete_integration_api_v1_aws_integrations_integration_id_delete(self) -> None:
        """Test case for delete_integration_api_v1_aws_integrations_integration_id_delete

        Delete Integration
        """
        pass

    def test_get_integration_api_v1_aws_integrations_integration_id_get(self) -> None:
        """Test case for get_integration_api_v1_aws_integrations_integration_id_get

        Get Integration
        """
        pass

    def test_get_workspace_integrations_api_v1_aws_integrations_workspace_workspace_id_get(self) -> None:
        """Test case for get_workspace_integrations_api_v1_aws_integrations_workspace_workspace_id_get

        Get Workspace Integrations
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.option import Option

class TestOption(unittest.TestCase):
    """Option unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Option:
        """Test Option
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Option`
        """
        model = Option()
        if include_optional:
            return Option(
                id = '',
                label = '',
                value = '',
                attributes = [
                    instalabel.client.models.attribute.Attribute(
                        id = '', 
                        name = '', 
                        type = 'radio', 
                        required = True, 
                        options = [
                            instalabel.client.models.option.Option(
                                id = '', 
                                label = '', 
                                value = '', )
                            ], )
                    ]
            )
        else:
            return Option(
                label = '',
                value = '',
        )
        """

    def testOption(self):
        """Test Option"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.api.auth_api import AuthApi


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthApi()

    def tearDown(self) -> None:
        pass

    def test_login_for_access_token_api_v1_auth_token_post(self) -> None:
        """Test case for login_for_access_token_api_v1_auth_token_post

        Login For Access Token
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.project_image_response import ProjectImageResponse

class TestProjectImageResponse(unittest.TestCase):
    """ProjectImageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectImageResponse:
        """Test ProjectImageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectImageResponse`
        """
        model = ProjectImageResponse()
        if include_optional:
            return ProjectImageResponse(
                images = [
                    instalabel.client.models.image_response.ImageResponse(
                        image_id = '', 
                        project_id = '', 
                        user_id = '', 
                        filename = '', 
                        status = '', 
                        annotations_count = 56, 
                        annotations = instalabel.client.models.annotation_data.AnnotationData(
                            rectangles = [
                                instalabel.client.models.b_box_annotation.BBoxAnnotation(
                                    id = '', 
                                    class_id = '', 
                                    class_name = '', 
                                    color = '', 
                                    type = 'boundingBox', 
                                    class_attributes_selections = {
                                        'key' : [
                                            ''
                                            ]
                                        }, 
                                    class_information = instalabel.client.models.class_information.ClassInformation(
                                        id = '', 
                                        name = '', 
                                        color = '', 
                                        description = '', 
                                        attributes_selections_id_map = {
                                            'key' : [
                                                ''
                                                ]
                                            }, 
                                        attributes_selections = [
                                            instalabel.client.models.attribute_selection.AttributeSelection(
                                                name = '', 
                                                labels = [
                                                    ''
                                                    ], 
                                                values = [
                                                    ''
                                                    ], )
                                            ], ), 
                                    x = 56, 
                                    y = 56, 
                                    width = 56, 
                                    height = 56, 
                                    fill = '', 
                                    stroke = '', )
                                ], 
                            polygons = [
                                instalabel.client.models.polygon_annotation.PolygonAnnotation(
                                    id = '', 
                                    class_id = '', 
                                    class_name = '', 
                                    color = '', 
                                    type = 'polygon', 
                                    class_attributes_selections = {
                                        'key' : [
                                            ''
                                            ]
                                        }, 
                                    class_information = instalabel.client.models.class_information.ClassInformation(
                                        id = '', 
                                        name = '', 
                                        color = '', 
                                        description = '', 
                                        attributes_selections_id_map = {
                                            'key' : [
                                                ''
                                                ]
                                            }, ), 
                                    points = [
                                        [
                                            56
                                            ]
                                        ], 
                                    is_complete = True, )
                                ], ), 
                        created_at = '', 
                        updated_at = '', 
                        presigned_url = '', )
                    ],
                next_key = '',
                count = 56
            )
        else:
            return ProjectImageResponse(
                images = [
                    instalabel.client.models.image_response.ImageResponse(
                        image_id = '', 
                        project_id = '', 
                        user_id = '', 
                        filename = '', 
                        status = '', 
                        annotations_count = 56, 
                        annotations = instalabel.client.models.annotation_data.AnnotationData(
                            rectangles = [
                                instalabel.client.models.b_box_annotation.BBoxAnnotation(
                                    id = '', 
                                    class_id = '', 
                                    class_name = '', 
                                    color = '', 
                                    type = 'boundingBox', 
                                    class_attributes_selections = {
                                        'key' : [
                                            ''
                                            ]
                                        }, 
                                    class_information = instalabel.client.models.class_information.ClassInformation(
                                        id = '', 
                                        name = '', 
                                        color = '', 
                                        description = '', 
                                        attributes_selections_id_map = {
                                            'key' : [
                                                ''
                                                ]
                                            }, 
                                        attributes_selections = [
                                            instalabel.client.models.attribute_selection.AttributeSelection(
                                                name = '', 
                                                labels = [
                                                    ''
                                                    ], 
                                                values = [
                                                    ''
                                                    ], )
                                            ], ), 
                                    x = 56, 
                                    y = 56, 
                                    width = 56, 
                                    height = 56, 
                                    fill = '', 
                                    stroke = '', )
                                ], 
                            polygons = [
                                instalabel.client.models.polygon_annotation.PolygonAnnotation(
                                    id = '', 
                                    class_id = '', 
                                    class_name = '', 
                                    color = '', 
                                    type = 'polygon', 
                                    class_attributes_selections = {
                                        'key' : [
                                            ''
                                            ]
                                        }, 
                                    class_information = instalabel.client.models.class_information.ClassInformation(
                                        id = '', 
                                        name = '', 
                                        color = '', 
                                        description = '', 
                                        attributes_selections_id_map = {
                                            'key' : [
                                                ''
                                                ]
                                            }, ), 
                                    points = [
                                        [
                                            56
                                            ]
                                        ], 
                                    is_complete = True, )
                                ], ), 
                        created_at = '', 
                        updated_at = '', 
                        presigned_url = '', )
                    ],
                count = 56,
        )
        """

    def testProjectImageResponse(self):
        """Test ProjectImageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



import instalabel.client

API_URL = "https://sua4nhu6ze.execute-api.us-east-1.amazonaws.com/prod"
DEFAULT_CONFIG_PATH_SUFFIX = "/.config/instalabel/config.json"
INSTALABEL_CLIENT_CONFIGURATION = instalabel.client.Configuration(host=API_URL)



# coding: utf-8

# flake8: noqa

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from instalabel.client.api.auth_api import AuthApi
from instalabel.client.api.aws_integrations_api import AwsIntegrationsApi
from instalabel.client.api.images_api import ImagesApi
from instalabel.client.api.projects_api import ProjectsApi
from instalabel.client.api.workspaces_api import WorkspacesApi

# import ApiClient
from instalabel.client.api_response import ApiResponse
from instalabel.client.api_client import ApiClient
from instalabel.client.configuration import Configuration
from instalabel.client.exceptions import OpenApiException
from instalabel.client.exceptions import ApiTypeError
from instalabel.client.exceptions import ApiValueError
from instalabel.client.exceptions import ApiKeyError
from instalabel.client.exceptions import ApiAttributeError
from instalabel.client.exceptions import ApiException

# import models into sdk package
from instalabel.client.models.aws_integration_create import AWSIntegrationCreate
from instalabel.client.models.aws_integration_response import AWSIntegrationResponse
from instalabel.client.models.annotation_data import AnnotationData
from instalabel.client.models.attribute import Attribute
from instalabel.client.models.attribute_selection import AttributeSelection
from instalabel.client.models.attribute_type import AttributeType
from instalabel.client.models.b_box_annotation import BBoxAnnotation
from instalabel.client.models.class_information import ClassInformation
from instalabel.client.models.coco_upload_request import CocoUploadRequest
from instalabel.client.models.credit_limits import CreditLimits
from instalabel.client.models.http_validation_error import HTTPValidationError
from instalabel.client.models.image_response import ImageResponse
from instalabel.client.models.ontology import Ontology
from instalabel.client.models.ontology_class import OntologyClass
from instalabel.client.models.option import Option
from instalabel.client.models.polygon_annotation import PolygonAnnotation
from instalabel.client.models.project_create import ProjectCreate
from instalabel.client.models.project_image_response import ProjectImageResponse
from instalabel.client.models.project_response import ProjectResponse
from instalabel.client.models.project_update_request import ProjectUpdateRequest
from instalabel.client.models.task_enum import TaskEnum
from instalabel.client.models.token import Token
from instalabel.client.models.validation_error import ValidationError
from instalabel.client.models.validation_error_loc_inner import ValidationErrorLocInner
from instalabel.client.models.workspace_create import WorkspaceCreate
from instalabel.client.models.workspace_credits import WorkspaceCredits
from instalabel.client.models.workspace_in_db import WorkspaceInDB



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import find_packages, setup  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "instalabel"
VERSION = "0.0.6"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
    "tqdm >= 4.66.4",
]

# Read the contents of your README file
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name=NAME,
    version=VERSION,
    description="InstaLabel Inc.",
    author="InstaLabel Inc.",
    author_email="aadil@instalabel.ai",
    url="",
    keywords=["InstaLabel"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type="text/markdown",
    long_description=long_description,
    package_data={"instalabel.client": ["py.typed"]},
)



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.annotation_data import AnnotationData

class TestAnnotationData(unittest.TestCase):
    """AnnotationData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnnotationData:
        """Test AnnotationData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnnotationData`
        """
        model = AnnotationData()
        if include_optional:
            return AnnotationData(
                rectangles = [
                    instalabel.client.models.b_box_annotation.BBoxAnnotation(
                        id = '', 
                        class_id = '', 
                        class_name = '', 
                        color = '', 
                        type = 'boundingBox', 
                        class_attributes_selections = {
                            'key' : [
                                ''
                                ]
                            }, 
                        class_information = instalabel.client.models.class_information.ClassInformation(
                            id = '', 
                            name = '', 
                            color = '', 
                            description = '', 
                            attributes_selections_id_map = {
                                'key' : [
                                    ''
                                    ]
                                }, 
                            attributes_selections = [
                                instalabel.client.models.attribute_selection.AttributeSelection(
                                    name = '', 
                                    labels = [
                                        ''
                                        ], 
                                    values = [
                                        ''
                                        ], )
                                ], ), 
                        x = 56, 
                        y = 56, 
                        width = 56, 
                        height = 56, 
                        fill = '', 
                        stroke = '', )
                    ],
                polygons = [
                    instalabel.client.models.polygon_annotation.PolygonAnnotation(
                        id = '', 
                        class_id = '', 
                        class_name = '', 
                        color = '', 
                        type = 'polygon', 
                        class_attributes_selections = {
                            'key' : [
                                ''
                                ]
                            }, 
                        class_information = instalabel.client.models.class_information.ClassInformation(
                            id = '', 
                            name = '', 
                            color = '', 
                            description = '', 
                            attributes_selections_id_map = {
                                'key' : [
                                    ''
                                    ]
                                }, 
                            attributes_selections = [
                                instalabel.client.models.attribute_selection.AttributeSelection(
                                    name = '', 
                                    labels = [
                                        ''
                                        ], 
                                    values = [
                                        ''
                                        ], )
                                ], ), 
                        points = [
                            [
                                56
                                ]
                            ], 
                        is_complete = True, )
                    ]
            )
        else:
            return AnnotationData(
        )
        """

    def testAnnotationData(self):
        """Test AnnotationData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.workspace_credits import WorkspaceCredits

class TestWorkspaceCredits(unittest.TestCase):
    """WorkspaceCredits unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkspaceCredits:
        """Test WorkspaceCredits
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkspaceCredits`
        """
        model = WorkspaceCredits()
        if include_optional:
            return WorkspaceCredits(
                image_uploads = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
                training_credits = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
                annotation_credits = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, )
            )
        else:
            return WorkspaceCredits(
                image_uploads = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
                training_credits = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
                annotation_credits = instalabel.client.models.credit_limits.CreditLimits(
                    total = 56, 
                    used = 56, ),
        )
        """

    def testWorkspaceCredits(self):
        """Test WorkspaceCredits"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



from typing import List, Optional

import instalabel.client
from instalabel.client.models.aws_integration_response import AWSIntegrationResponse
from instalabel.client.models.project_create import ProjectCreate
from instalabel.client.models.task_enum import TaskEnum
from instalabel.client.models.workspace_create import WorkspaceCreate
from instalabel.client.models.workspace_credits import WorkspaceCredits
from instalabel.client.models.workspace_in_db import WorkspaceInDB
from instalabel.config import INSTALABEL_CLIENT_CONFIGURATION as configuration
from instalabel.core.project import Project


class Workspace:
    def __init__(self, workspace: WorkspaceInDB):
        """Initialize a workspace instance"""
        self.id = workspace.workspace_id
        self.name = workspace.workspace_name
        self.description = workspace.description
        self.created_at = workspace.created_at
        self.updated_at = workspace.updated_at
        self.credits = workspace.credits

    @classmethod
    def create(cls, workspace_name: str, description: str = None) -> "Workspace":
        """Create a new workspace"""
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.WorkspacesApi(api_client)
            workspace_create = WorkspaceCreate(
                workspace_name=workspace_name, description=description
            )

            try:
                api_response = api_instance.create_workspace_api_v1_workspaces_post(
                    workspace_create
                )
                return cls(api_response)
            except Exception as e:
                print(f"Exception when creating workspace: {e}")
                return None

    def create_project(
        self, project_name: str, task: TaskEnum, project_description: str = ""
    ) -> Optional[Project]:
        """Create a new project in the workspace"""
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.ProjectsApi(api_client)
            project_create = ProjectCreate(
                workspace_id=self.id,
                project_name=project_name,
                project_description=project_description,
                task=task,
            )

            try:
                api_response = api_instance.create_project_api_v1_projects_post(
                    workspace_id=self.id, project_create=project_create
                )
                return Project(api_response)
            except Exception as e:
                print(f"Exception when creating project: {e}")
                return None

    def get_projects(self) -> List[Project]:
        """Get all projects in the workspace"""
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.ProjectsApi(api_client)

            try:
                api_response = api_instance.read_projects_api_v1_projects_get(
                    workspace_id=self.id
                )
                return [Project(project) for project in api_response]
            except Exception as e:
                print(f"Exception when getting projects: {e}")
                return []

    def get_credits(self) -> Optional[WorkspaceCredits]:
        """Get workspace credits information"""
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.WorkspacesApi(api_client)

            try:
                api_response = (
                    api_instance.read_workspace_api_v1_workspaces_workspace_id_get(
                        workspace_id=self.id
                    )
                )
                return api_response.credits
            except Exception as e:
                print(f"Exception when getting workspace credits: {e}")
                return None

    def get_integrations(self) -> List[AWSIntegrationResponse]:
        """Get all AWS integrations for the workspace

        Returns:
            List[AWSIntegrationResponse]: List of AWS integrations for this workspace
        """
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.AwsIntegrationsApi(api_client)

            try:
                api_response = api_instance.get_workspace_integrations_api_v1_aws_integrations_workspace_workspace_id_get(
                    workspace_id=self.id
                )
                return api_response
            except Exception as e:
                print(f"Exception when getting AWS integrations: {e}")
                return []

    def get_project(self, project_id: str) -> Optional[Project]:
        """Get a specific project by ID from the workspace

        Args:
            project_id (str): The ID of the project to retrieve

        Returns:
            Optional[Project]: The project if found, None otherwise
        """
        with instalabel.client.ApiClient(configuration) as api_client:
            api_instance = instalabel.client.ProjectsApi(api_client)

            try:
                api_response = api_instance.read_project_api_v1_projects_project_id_get(
                    project_id=project_id
                )
                return Project(api_response)
            except Exception as e:
                print(f"Exception when getting project: {e}")
                return None

    def __str__(self):
        return f"Workspace(ID: {self.id}, Name: {self.name})"



from __future__ import annotations

from datetime import datetime
from enum import Enum
from typing import Any, Dict, List, Optional, Union

from pydantic import BaseModel, Field, HttpUrl, field_validator


class Info(BaseModel):
    year: int
    version: str
    description: str
    contributor: str
    url: str
    # date_created is expected in ISO format; if parsing fails it remains a string.
    date_created: Union[datetime, str]

    @field_validator("date_created", mode="before")
    def parse_date_created(cls, v):
        if isinstance(v, str):
            try:
                return datetime.fromisoformat(v)
            except ValueError:
                # Return as-is if parsing fails
                return v
        return v


class License(BaseModel):
    id: int
    name: str
    url: Optional[str] = None


class Image(BaseModel):
    id: int
    width: int
    height: int
    file_name: str
    # Optional additional fields.
    license: Optional[int] = None
    flickr_url: Optional[str] = None
    coco_url: Optional[str] = None
    date_captured: Optional[Union[datetime, str]] = None

    @field_validator("date_captured", mode="before")
    def parse_date_captured(cls, v):
        if v is None:
            return v
        if isinstance(v, str):
            try:
                return datetime.fromisoformat(v)
            except ValueError:
                return v
        return v


class Annotation(BaseModel):
    id: int
    image_id: int
    category_id: int
    # segmentation in COCO can be a list of lists (for polygons) or a dict (for RLE)
    segmentation: Optional[Union[List[float], List[List[float]], dict]] = None
    area: float
    bbox: List[float]
    iscrowd: int

    @field_validator("bbox")
    def validate_bbox_length(cls, v):
        if len(v) != 4:
            raise ValueError("bbox must be a list of 4 numbers [x, y, width, height]")
        return v


class Category(BaseModel):
    id: int
    name: str
    supercategory: Optional[str] = None


# --- Define the top-level COCO dataset model ---
#
# Optional fields (like "info" and "licenses") are allowed to be missing.
# An extra field, e.g. "bbox_format", can also be supported if needed.


class CocoDataset(BaseModel):
    info: Optional[Info] = None
    licenses: Optional[List[License]] = None
    images: List[Image]
    annotations: List[Annotation]
    categories: List[Category]
    bbox_format: Optional[str] = None
    categories: List[Category]
    bbox_format: Optional[str] = None
